package com.zd.laboratory.service.impl;

import java.util.List;

import com.zd.common.core.utils.DateUtils;
import com.zd.common.datascope.annotation.DataScope;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zd.laboratory.mapper.LabOnepcMapper;
import com.zd.laboratory.domain.LabOnepc;
import com.zd.laboratory.service.ILabOnepcService;

/**
 * 一体机设备勾选Service业务层处理
 *
 * @author zd
 * @date 2021-08-31
 */
@Service
public class LabOnepcServiceImpl implements ILabOnepcService {
    @Autowired
    private LabOnepcMapper labOnepcMapper;

    /**
     * 查询一体机设备勾选
     *
     * @param id 一体机设备勾选主键
     * @return 一体机设备勾选
     */
    @Override
    public LabOnepc selectLabOnepcById(Long id) {
        return labOnepcMapper.selectLabOnepcById(id);
    }

    /**
     * 查询一体机设备勾选列表
     *
     * @param labOnepc 一体机设备勾选
     * @return 一体机设备勾选
     */
    @Override
    @DataScope(deptAlias = "o")
    public List<LabOnepc> selectLabOnepcList(LabOnepc labOnepc) {
        return labOnepcMapper.selectLabOnepcList(labOnepc);
    }

    /**
     * 新增一体机设备勾选
     *
     * @param labOnepc 一体机设备勾选
     * @return 结果
     */
    @Override
    public int insertLabOnepc(LabOnepc labOnepc) {
        labOnepc.setCreateTime(DateUtils.getNowDate());
        return labOnepcMapper.insertLabOnepc(labOnepc);
    }

    /**
     * 修改一体机设备勾选
     *
     * @param labOnepc 一体机设备勾选
     * @return 结果
     */
    @Override
    public int updateLabOnepc(LabOnepc labOnepc) {
        labOnepc.setUpdateTime(DateUtils.getNowDate());
        return labOnepcMapper.updateLabOnepc(labOnepc);
    }

    /**
     * 批量删除一体机设备勾选
     *
     * @param ids 需要删除的一体机设备勾选主键
     * @return 结果
     */
    @Override
    public int deleteLabOnepcByIds(Long[] ids) {
        return labOnepcMapper.deleteLabOnepcByIds(ids);
    }

    /**
     * 删除一体机设备勾选信息
     *
     * @param id 一体机设备勾选主键
     * @return 结果
     */
    @Override
    public int deleteLabOnepcById(Long id) {
        return labOnepcMapper.deleteLabOnepcById(id);
    }
}
